<h1 align="center">Django hogwarts</h1>
<h4 align="center">bring magic to you development ✨</h4>

Set of utilities and CLI tools to speed up django development
and do repetitive stuff

# THIS REPO IS UNDER CONSTRUCTION 🚧
### first beta will be till september 2023
